@@ -2,7 +2,7 @@
  * message.cpp : SAP Message class
  ****************************************************************************
  * Copyright (C) 1998-2006 the VideoLAN team
- * $Id: message.cpp 328 2007-03-11 12:21:00Z courmisch $
+ * $Id: message.cpp 341 2008-06-30 16:31:16Z courmisch $
  *
  * Authors: Damien Lucas <nitrox@videolan.org>
  *          Philippe Van Hecke <philippe.vanhecke@belnet.be>
@@ -24,18 +24,15 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
-#include <sys/types.h>
-#include <netinet/in.h>
 #include <arpa/inet.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <string.h>
 #include <string>
 #include <sstream>
 #include <vector>
 using namespace std;
 
-#include <sys/time.h>
-
 #include "sapserver.h"
 #include "program.h"
 #include "message.h"
@@ -134,7 +131,7 @@ bool Message::AddProgram(Program *p)
     sdp += "a=charset:UTF-8\r\n";
 
     string m = "m=video " + p->GetPort() + " "
-             + (p->IsRTP() ? "RTP/AVP" : "udp") +" 33\r\n";
+             + (p->IsRTP() ? "RTP/AVP 33" : "udp mpeg") +"\r\n";
 
     if (p->IsRTP())
         m += "a=rtpmap:33 MP2T/90000\r\n";
